==> zio-aws-wisdom_3-5.17.127.2-sources.jar: zio/aws/wisdom/model/GetContentResponse.scala <==
package zio.aws.wisdom.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetContentResponse(
    content: Option[zio.aws.wisdom.model.ContentData] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.wisdom.model.GetContentResponse = {
    import GetContentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.wisdom.model.GetContentResponse
      .builder()
      .optionallyWith(content.map(value => value.buildAwsValue()))(_.content)
      .build()
  }
  def asReadOnly: zio.aws.wisdom.model.GetContentResponse.ReadOnly =
    zio.aws.wisdom.model.GetContentResponse.wrap(buildAwsValue())
}
object GetContentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.wisdom.model.GetContentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wisdom.model.GetContentResponse =
      zio.aws.wisdom.model
        .GetContentResponse(content.map(value => value.asEditable))
    def content: Option[zio.aws.wisdom.model.ContentData.ReadOnly]
    def getContent
        : ZIO[Any, AwsError, zio.aws.wisdom.model.ContentData.ReadOnly] =
      AwsError.unwrapOptionField("content", content)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.wisdom.model.GetContentResponse
  ) extends zio.aws.wisdom.model.GetContentResponse.ReadOnly {
    override val content: Option[zio.aws.wisdom.model.ContentData.ReadOnly] =
      scala
        .Option(impl.content())
        .map(value => zio.aws.wisdom.model.ContentData.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.wisdom.model.GetContentResponse
  ): zio.aws.wisdom.model.GetContentResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-wisdom_3-5.17.172.2-sources.jar: zio/aws/wisdom/model/GetContentResponse.scala <==
package zio.aws.wisdom.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetContentResponse(
    content: Optional[zio.aws.wisdom.model.ContentData] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.wisdom.model.GetContentResponse = {
    import GetContentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.wisdom.model.GetContentResponse
      .builder()
      .optionallyWith(content.map(value => value.buildAwsValue()))(_.content)
      .build()
  }
  def asReadOnly: zio.aws.wisdom.model.GetContentResponse.ReadOnly =
    zio.aws.wisdom.model.GetContentResponse.wrap(buildAwsValue())
}
object GetContentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.wisdom.model.GetContentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wisdom.model.GetContentResponse =
      zio.aws.wisdom.model
        .GetContentResponse(content.map(value => value.asEditable))
    def content: Optional[zio.aws.wisdom.model.ContentData.ReadOnly]
    def getContent
        : ZIO[Any, AwsError, zio.aws.wisdom.model.ContentData.ReadOnly] =
      AwsError.unwrapOptionField("content", content)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.wisdom.model.GetContentResponse
  ) extends zio.aws.wisdom.model.GetContentResponse.ReadOnly {
    override val content: Optional[zio.aws.wisdom.model.ContentData.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.content())
        .map(value => zio.aws.wisdom.model.ContentData.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.wisdom.model.GetContentResponse
  ): zio.aws.wisdom.model.GetContentResponse.ReadOnly = new Wrapper(impl)
}
